/*
    Copyright (C) 2005-2007  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "gui.h"

#ifdef HAVE_LIBNOTIFY

#include <libnotify/notify.h>

static void
file_download_done (NNTPGrabCore *core, const char *collection_name, const char *subject, gpointer data)
{
    char *msg;
    NotifyNotification *notification;
    ConfigOpts opts;

    opts = nntpgrab_config_get_opts(core);
    if (!opts.show_notification_on_file_downloaded) {
        return;
    }

    msg = g_strdup_printf(_("All the parts belonging to the post with subject\n<span style='italic'>%s</span>\nare now downloaded and will soon be decoded"), subject);
    notification = notify_notification_new(_("File download done"), msg, NULL, NULL);
    g_free(msg);

    notify_notification_show(notification, NULL);
}

static void
file_decode_done (NNTPGrabCore *core, const char *collection_name, const char *subject, gpointer data)
{
    char *msg;
    NotifyNotification *notification;
    ConfigOpts opts;

    opts = nntpgrab_config_get_opts(core);
    if (!opts.show_notification_on_file_decoded) {
        return;
    }

    msg = g_strdup_printf(_("The file belonging to the post with subject\n<span style='italic'>%s</span>\nis now decoded"), subject);
    notification = notify_notification_new(_("File decode done"), msg, NULL, NULL);
    g_free(msg);

    notify_notification_show(notification, NULL);
}

void
notify_initialize(void)
{
    if (!notify_init(PACKAGE)) {
        GtkWidget *windowMain = get_widget("windowMain");
        dialog_show(windowMain, _("Libnotify could not be initialised.\nNotification bubbles will be disabled"), GTK_MESSAGE_ERROR, GTK_BUTTONS_OK);

        return;
    }

    g_signal_connect(core, "file_download_done", G_CALLBACK(file_download_done), NULL);
    g_signal_connect(core, "file_decode_done", G_CALLBACK(file_decode_done), NULL);
}

#else /* HAVE_LIBNOTIFY */

void
notify_initialize(void)
{
}

#endif /* HAVE_LIBNOTIFY */
